# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class StockCandles(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'o': 'list[float]',
        'h': 'list[float]',
        'l': 'list[float]',
        'c': 'list[float]',
        'v': 'list[float]',
        't': 'list[int]',
        's': 'str'
    }

    attribute_map = {
        'o': 'o',
        'h': 'h',
        'l': 'l',
        'c': 'c',
        'v': 'v',
        't': 't',
        's': 's'
    }

    def __init__(self, o=None, h=None, l=None, c=None, v=None, t=None, s=None, local_vars_configuration=None):  # noqa: E501
        """StockCandles - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._o = None
        self._h = None
        self._l = None
        self._c = None
        self._v = None
        self._t = None
        self._s = None
        self.discriminator = None

        if o is not None:
            self.o = o
        if h is not None:
            self.h = h
        if l is not None:
            self.l = l
        if c is not None:
            self.c = c
        if v is not None:
            self.v = v
        if t is not None:
            self.t = t
        if s is not None:
            self.s = s

    @property
    def o(self):
        """Gets the o of this StockCandles.  # noqa: E501

        List of open prices for returned candles.  # noqa: E501

        :return: The o of this StockCandles.  # noqa: E501
        :rtype: list[float]
        """
        return self._o

    @o.setter
    def o(self, o):
        """Sets the o of this StockCandles.

        List of open prices for returned candles.  # noqa: E501

        :param o: The o of this StockCandles.  # noqa: E501
        :type: list[float]
        """

        self._o = o

    @property
    def h(self):
        """Gets the h of this StockCandles.  # noqa: E501

        List of high prices for returned candles.  # noqa: E501

        :return: The h of this StockCandles.  # noqa: E501
        :rtype: list[float]
        """
        return self._h

    @h.setter
    def h(self, h):
        """Sets the h of this StockCandles.

        List of high prices for returned candles.  # noqa: E501

        :param h: The h of this StockCandles.  # noqa: E501
        :type: list[float]
        """

        self._h = h

    @property
    def l(self):
        """Gets the l of this StockCandles.  # noqa: E501

        List of low prices for returned candles.  # noqa: E501

        :return: The l of this StockCandles.  # noqa: E501
        :rtype: list[float]
        """
        return self._l

    @l.setter
    def l(self, l):
        """Sets the l of this StockCandles.

        List of low prices for returned candles.  # noqa: E501

        :param l: The l of this StockCandles.  # noqa: E501
        :type: list[float]
        """

        self._l = l

    @property
    def c(self):
        """Gets the c of this StockCandles.  # noqa: E501

        List of close prices for returned candles.  # noqa: E501

        :return: The c of this StockCandles.  # noqa: E501
        :rtype: list[float]
        """
        return self._c

    @c.setter
    def c(self, c):
        """Sets the c of this StockCandles.

        List of close prices for returned candles.  # noqa: E501

        :param c: The c of this StockCandles.  # noqa: E501
        :type: list[float]
        """

        self._c = c

    @property
    def v(self):
        """Gets the v of this StockCandles.  # noqa: E501

        List of volume data for returned candles.  # noqa: E501

        :return: The v of this StockCandles.  # noqa: E501
        :rtype: list[float]
        """
        return self._v

    @v.setter
    def v(self, v):
        """Sets the v of this StockCandles.

        List of volume data for returned candles.  # noqa: E501

        :param v: The v of this StockCandles.  # noqa: E501
        :type: list[float]
        """

        self._v = v

    @property
    def t(self):
        """Gets the t of this StockCandles.  # noqa: E501

        List of timestamp for returned candles.  # noqa: E501

        :return: The t of this StockCandles.  # noqa: E501
        :rtype: list[int]
        """
        return self._t

    @t.setter
    def t(self, t):
        """Sets the t of this StockCandles.

        List of timestamp for returned candles.  # noqa: E501

        :param t: The t of this StockCandles.  # noqa: E501
        :type: list[int]
        """

        self._t = t

    @property
    def s(self):
        """Gets the s of this StockCandles.  # noqa: E501

        Status of the response. This field can either be ok or no_data.  # noqa: E501

        :return: The s of this StockCandles.  # noqa: E501
        :rtype: str
        """
        return self._s

    @s.setter
    def s(self, s):
        """Sets the s of this StockCandles.

        Status of the response. This field can either be ok or no_data.  # noqa: E501

        :param s: The s of this StockCandles.  # noqa: E501
        :type: str
        """

        self._s = s

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StockCandles):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StockCandles):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class TickData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        's': 'str',
        'skip': 'int',
        'count': 'int',
        'total': 'int',
        'v': 'list[float]',
        'p': 'list[float]',
        't': 'list[int]',
        'x': 'list[str]'
    }

    attribute_map = {
        's': 's',
        'skip': 'skip',
        'count': 'count',
        'total': 'total',
        'v': 'v',
        'p': 'p',
        't': 't',
        'x': 'x'
    }

    def __init__(self, s=None, skip=None, count=None, total=None, v=None, p=None, t=None, x=None, local_vars_configuration=None):  # noqa: E501
        """TickData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._s = None
        self._skip = None
        self._count = None
        self._total = None
        self._v = None
        self._p = None
        self._t = None
        self._x = None
        self.discriminator = None

        if s is not None:
            self.s = s
        if skip is not None:
            self.skip = skip
        if count is not None:
            self.count = count
        if total is not None:
            self.total = total
        if v is not None:
            self.v = v
        if p is not None:
            self.p = p
        if t is not None:
            self.t = t
        if x is not None:
            self.x = x

    @property
    def s(self):
        """Gets the s of this TickData.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The s of this TickData.  # noqa: E501
        :rtype: str
        """
        return self._s

    @s.setter
    def s(self, s):
        """Sets the s of this TickData.

        Symbol.  # noqa: E501

        :param s: The s of this TickData.  # noqa: E501
        :type: str
        """

        self._s = s

    @property
    def skip(self):
        """Gets the skip of this TickData.  # noqa: E501

        Number of ticks skipped.  # noqa: E501

        :return: The skip of this TickData.  # noqa: E501
        :rtype: int
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this TickData.

        Number of ticks skipped.  # noqa: E501

        :param skip: The skip of this TickData.  # noqa: E501
        :type: int
        """

        self._skip = skip

    @property
    def count(self):
        """Gets the count of this TickData.  # noqa: E501

        Number of ticks returned. If <code>count</code> < <code>limit</code>, all data for that date has been returned.  # noqa: E501

        :return: The count of this TickData.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this TickData.

        Number of ticks returned. If <code>count</code> < <code>limit</code>, all data for that date has been returned.  # noqa: E501

        :param count: The count of this TickData.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def total(self):
        """Gets the total of this TickData.  # noqa: E501

        Total number of ticks for that date.  # noqa: E501

        :return: The total of this TickData.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this TickData.

        Total number of ticks for that date.  # noqa: E501

        :param total: The total of this TickData.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def v(self):
        """Gets the v of this TickData.  # noqa: E501

        List of volume data.  # noqa: E501

        :return: The v of this TickData.  # noqa: E501
        :rtype: list[float]
        """
        return self._v

    @v.setter
    def v(self, v):
        """Sets the v of this TickData.

        List of volume data.  # noqa: E501

        :param v: The v of this TickData.  # noqa: E501
        :type: list[float]
        """

        self._v = v

    @property
    def p(self):
        """Gets the p of this TickData.  # noqa: E501

        List of price data.  # noqa: E501

        :return: The p of this TickData.  # noqa: E501
        :rtype: list[float]
        """
        return self._p

    @p.setter
    def p(self, p):
        """Sets the p of this TickData.

        List of price data.  # noqa: E501

        :param p: The p of this TickData.  # noqa: E501
        :type: list[float]
        """

        self._p = p

    @property
    def t(self):
        """Gets the t of this TickData.  # noqa: E501

        List of timestamp in UNIX ms.  # noqa: E501

        :return: The t of this TickData.  # noqa: E501
        :rtype: list[int]
        """
        return self._t

    @t.setter
    def t(self, t):
        """Sets the t of this TickData.

        List of timestamp in UNIX ms.  # noqa: E501

        :param t: The t of this TickData.  # noqa: E501
        :type: list[int]
        """

        self._t = t

    @property
    def x(self):
        """Gets the x of this TickData.  # noqa: E501

        List of venues/exchanges.  # noqa: E501

        :return: The x of this TickData.  # noqa: E501
        :rtype: list[str]
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this TickData.

        List of venues/exchanges.  # noqa: E501

        :param x: The x of this TickData.  # noqa: E501
        :type: list[str]
        """

        self._x = x

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TickData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TickData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class CountryMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'country': 'str',
        'code2': 'str',
        'code3': 'str',
        'code_no': 'str',
        'currency': 'str',
        'currency_code': 'str'
    }

    attribute_map = {
        'country': 'country',
        'code2': 'code2',
        'code3': 'code3',
        'code_no': 'codeNo',
        'currency': 'currency',
        'currency_code': 'currencyCode'
    }

    def __init__(self, country=None, code2=None, code3=None, code_no=None, currency=None, currency_code=None, local_vars_configuration=None):  # noqa: E501
        """CountryMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._country = None
        self._code2 = None
        self._code3 = None
        self._code_no = None
        self._currency = None
        self._currency_code = None
        self.discriminator = None

        if country is not None:
            self.country = country
        if code2 is not None:
            self.code2 = code2
        if code3 is not None:
            self.code3 = code3
        if code_no is not None:
            self.code_no = code_no
        if currency is not None:
            self.currency = currency
        if currency_code is not None:
            self.currency_code = currency_code

    @property
    def country(self):
        """Gets the country of this CountryMetadata.  # noqa: E501

        Country name  # noqa: E501

        :return: The country of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this CountryMetadata.

        Country name  # noqa: E501

        :param country: The country of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def code2(self):
        """Gets the code2 of this CountryMetadata.  # noqa: E501

        Alpha 2 code  # noqa: E501

        :return: The code2 of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._code2

    @code2.setter
    def code2(self, code2):
        """Sets the code2 of this CountryMetadata.

        Alpha 2 code  # noqa: E501

        :param code2: The code2 of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._code2 = code2

    @property
    def code3(self):
        """Gets the code3 of this CountryMetadata.  # noqa: E501

        Alpha 3 code  # noqa: E501

        :return: The code3 of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._code3

    @code3.setter
    def code3(self, code3):
        """Sets the code3 of this CountryMetadata.

        Alpha 3 code  # noqa: E501

        :param code3: The code3 of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._code3 = code3

    @property
    def code_no(self):
        """Gets the code_no of this CountryMetadata.  # noqa: E501

        UN code  # noqa: E501

        :return: The code_no of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._code_no

    @code_no.setter
    def code_no(self, code_no):
        """Sets the code_no of this CountryMetadata.

        UN code  # noqa: E501

        :param code_no: The code_no of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._code_no = code_no

    @property
    def currency(self):
        """Gets the currency of this CountryMetadata.  # noqa: E501

        Currency name  # noqa: E501

        :return: The currency of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this CountryMetadata.

        Currency name  # noqa: E501

        :param currency: The currency of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def currency_code(self):
        """Gets the currency_code of this CountryMetadata.  # noqa: E501

        Currency code  # noqa: E501

        :return: The currency_code of this CountryMetadata.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this CountryMetadata.

        Currency code  # noqa: E501

        :param currency_code: The currency_code of this CountryMetadata.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CountryMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CountryMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class IPOEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'date': 'date',
        'exchange': 'str',
        'name': 'str',
        'status': 'str',
        'price': 'str',
        'number_of_shares': 'int',
        'total_shares_value': 'int'
    }

    attribute_map = {
        'symbol': 'symbol',
        'date': 'date',
        'exchange': 'exchange',
        'name': 'name',
        'status': 'status',
        'price': 'price',
        'number_of_shares': 'numberOfShares',
        'total_shares_value': 'totalSharesValue'
    }

    def __init__(self, symbol=None, date=None, exchange=None, name=None, status=None, price=None, number_of_shares=None, total_shares_value=None, local_vars_configuration=None):  # noqa: E501
        """IPOEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._date = None
        self._exchange = None
        self._name = None
        self._status = None
        self._price = None
        self._number_of_shares = None
        self._total_shares_value = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if date is not None:
            self.date = date
        if exchange is not None:
            self.exchange = exchange
        if name is not None:
            self.name = name
        if status is not None:
            self.status = status
        if price is not None:
            self.price = price
        if number_of_shares is not None:
            self.number_of_shares = number_of_shares
        if total_shares_value is not None:
            self.total_shares_value = total_shares_value

    @property
    def symbol(self):
        """Gets the symbol of this IPOEvent.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The symbol of this IPOEvent.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this IPOEvent.

        Symbol.  # noqa: E501

        :param symbol: The symbol of this IPOEvent.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def date(self):
        """Gets the date of this IPOEvent.  # noqa: E501

        IPO date.  # noqa: E501

        :return: The date of this IPOEvent.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this IPOEvent.

        IPO date.  # noqa: E501

        :param date: The date of this IPOEvent.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def exchange(self):
        """Gets the exchange of this IPOEvent.  # noqa: E501

        Exchange.  # noqa: E501

        :return: The exchange of this IPOEvent.  # noqa: E501
        :rtype: str
        """
        return self._exchange

    @exchange.setter
    def exchange(self, exchange):
        """Sets the exchange of this IPOEvent.

        Exchange.  # noqa: E501

        :param exchange: The exchange of this IPOEvent.  # noqa: E501
        :type: str
        """

        self._exchange = exchange

    @property
    def name(self):
        """Gets the name of this IPOEvent.  # noqa: E501

        Company's name.  # noqa: E501

        :return: The name of this IPOEvent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IPOEvent.

        Company's name.  # noqa: E501

        :param name: The name of this IPOEvent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status(self):
        """Gets the status of this IPOEvent.  # noqa: E501

        IPO status. Can take 1 of the following values: <code>expected</code>,<code>priced</code>,<code>withdrawn</code>,<code>filed</code>  # noqa: E501

        :return: The status of this IPOEvent.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this IPOEvent.

        IPO status. Can take 1 of the following values: <code>expected</code>,<code>priced</code>,<code>withdrawn</code>,<code>filed</code>  # noqa: E501

        :param status: The status of this IPOEvent.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def price(self):
        """Gets the price of this IPOEvent.  # noqa: E501

        Projected price or price range.  # noqa: E501

        :return: The price of this IPOEvent.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this IPOEvent.

        Projected price or price range.  # noqa: E501

        :param price: The price of this IPOEvent.  # noqa: E501
        :type: str
        """

        self._price = price

    @property
    def number_of_shares(self):
        """Gets the number_of_shares of this IPOEvent.  # noqa: E501

        Number of shares offered during the IPO.  # noqa: E501

        :return: The number_of_shares of this IPOEvent.  # noqa: E501
        :rtype: int
        """
        return self._number_of_shares

    @number_of_shares.setter
    def number_of_shares(self, number_of_shares):
        """Sets the number_of_shares of this IPOEvent.

        Number of shares offered during the IPO.  # noqa: E501

        :param number_of_shares: The number_of_shares of this IPOEvent.  # noqa: E501
        :type: int
        """

        self._number_of_shares = number_of_shares

    @property
    def total_shares_value(self):
        """Gets the total_shares_value of this IPOEvent.  # noqa: E501

        Total shares value.  # noqa: E501

        :return: The total_shares_value of this IPOEvent.  # noqa: E501
        :rtype: int
        """
        return self._total_shares_value

    @total_shares_value.setter
    def total_shares_value(self, total_shares_value):
        """Sets the total_shares_value of this IPOEvent.

        Total shares value.  # noqa: E501

        :param total_shares_value: The total_shares_value of this IPOEvent.  # noqa: E501
        :type: int
        """

        self._total_shares_value = total_shares_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IPOEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IPOEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class Report(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_number': 'str',
        'symbol': 'str',
        'cik': 'str',
        'year': 'int',
        'quarter': 'int',
        'form': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'filed_date': 'datetime',
        'accepted_date': 'datetime',
        'report': 'object'
    }

    attribute_map = {
        'access_number': 'accessNumber',
        'symbol': 'symbol',
        'cik': 'cik',
        'year': 'year',
        'quarter': 'quarter',
        'form': 'form',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'filed_date': 'filedDate',
        'accepted_date': 'acceptedDate',
        'report': 'report'
    }

    def __init__(self, access_number=None, symbol=None, cik=None, year=None, quarter=None, form=None, start_date=None, end_date=None, filed_date=None, accepted_date=None, report=None, local_vars_configuration=None):  # noqa: E501
        """Report - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_number = None
        self._symbol = None
        self._cik = None
        self._year = None
        self._quarter = None
        self._form = None
        self._start_date = None
        self._end_date = None
        self._filed_date = None
        self._accepted_date = None
        self._report = None
        self.discriminator = None

        if access_number is not None:
            self.access_number = access_number
        if symbol is not None:
            self.symbol = symbol
        if cik is not None:
            self.cik = cik
        if year is not None:
            self.year = year
        if quarter is not None:
            self.quarter = quarter
        if form is not None:
            self.form = form
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if filed_date is not None:
            self.filed_date = filed_date
        if accepted_date is not None:
            self.accepted_date = accepted_date
        if report is not None:
            self.report = report

    @property
    def access_number(self):
        """Gets the access_number of this Report.  # noqa: E501

        Access number.  # noqa: E501

        :return: The access_number of this Report.  # noqa: E501
        :rtype: str
        """
        return self._access_number

    @access_number.setter
    def access_number(self, access_number):
        """Sets the access_number of this Report.

        Access number.  # noqa: E501

        :param access_number: The access_number of this Report.  # noqa: E501
        :type: str
        """

        self._access_number = access_number

    @property
    def symbol(self):
        """Gets the symbol of this Report.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The symbol of this Report.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Report.

        Symbol.  # noqa: E501

        :param symbol: The symbol of this Report.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def cik(self):
        """Gets the cik of this Report.  # noqa: E501

        CIK.  # noqa: E501

        :return: The cik of this Report.  # noqa: E501
        :rtype: str
        """
        return self._cik

    @cik.setter
    def cik(self, cik):
        """Sets the cik of this Report.

        CIK.  # noqa: E501

        :param cik: The cik of this Report.  # noqa: E501
        :type: str
        """

        self._cik = cik

    @property
    def year(self):
        """Gets the year of this Report.  # noqa: E501

        Year.  # noqa: E501

        :return: The year of this Report.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this Report.

        Year.  # noqa: E501

        :param year: The year of this Report.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def quarter(self):
        """Gets the quarter of this Report.  # noqa: E501

        Quarter.  # noqa: E501

        :return: The quarter of this Report.  # noqa: E501
        :rtype: int
        """
        return self._quarter

    @quarter.setter
    def quarter(self, quarter):
        """Sets the quarter of this Report.

        Quarter.  # noqa: E501

        :param quarter: The quarter of this Report.  # noqa: E501
        :type: int
        """

        self._quarter = quarter

    @property
    def form(self):
        """Gets the form of this Report.  # noqa: E501

        Form type.  # noqa: E501

        :return: The form of this Report.  # noqa: E501
        :rtype: str
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this Report.

        Form type.  # noqa: E501

        :param form: The form of this Report.  # noqa: E501
        :type: str
        """

        self._form = form

    @property
    def start_date(self):
        """Gets the start_date of this Report.  # noqa: E501

        Period start date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The start_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Report.

        Period start date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param start_date: The start_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Report.  # noqa: E501

        Period end date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The end_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Report.

        Period end date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param end_date: The end_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def filed_date(self):
        """Gets the filed_date of this Report.  # noqa: E501

        Filed date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The filed_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._filed_date

    @filed_date.setter
    def filed_date(self, filed_date):
        """Sets the filed_date of this Report.

        Filed date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param filed_date: The filed_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._filed_date = filed_date

    @property
    def accepted_date(self):
        """Gets the accepted_date of this Report.  # noqa: E501

        Accepted date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The accepted_date of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._accepted_date

    @accepted_date.setter
    def accepted_date(self, accepted_date):
        """Sets the accepted_date of this Report.

        Accepted date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param accepted_date: The accepted_date of this Report.  # noqa: E501
        :type: datetime
        """

        self._accepted_date = accepted_date

    @property
    def report(self):
        """Gets the report of this Report.  # noqa: E501


        :return: The report of this Report.  # noqa: E501
        :rtype: object
        """
        return self._report

    @report.setter
    def report(self, report):
        """Sets the report of this Report.


        :param report: The report of this Report.  # noqa: E501
        :type: object
        """

        self._report = report

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Report):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class EarningRelease(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'date': 'date',
        'hour': 'str',
        'year': 'int',
        'quarter': 'int',
        'eps_estimate': 'float',
        'eps_actual': 'float',
        'revenue_estimate': 'int',
        'revenue_actual': 'int'
    }

    attribute_map = {
        'symbol': 'symbol',
        'date': 'date',
        'hour': 'hour',
        'year': 'year',
        'quarter': 'quarter',
        'eps_estimate': 'epsEstimate',
        'eps_actual': 'epsActual',
        'revenue_estimate': 'revenueEstimate',
        'revenue_actual': 'revenueActual'
    }

    def __init__(self, symbol=None, date=None, hour=None, year=None, quarter=None, eps_estimate=None, eps_actual=None, revenue_estimate=None, revenue_actual=None, local_vars_configuration=None):  # noqa: E501
        """EarningRelease - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._date = None
        self._hour = None
        self._year = None
        self._quarter = None
        self._eps_estimate = None
        self._eps_actual = None
        self._revenue_estimate = None
        self._revenue_actual = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if date is not None:
            self.date = date
        if hour is not None:
            self.hour = hour
        if year is not None:
            self.year = year
        if quarter is not None:
            self.quarter = quarter
        if eps_estimate is not None:
            self.eps_estimate = eps_estimate
        if eps_actual is not None:
            self.eps_actual = eps_actual
        if revenue_estimate is not None:
            self.revenue_estimate = revenue_estimate
        if revenue_actual is not None:
            self.revenue_actual = revenue_actual

    @property
    def symbol(self):
        """Gets the symbol of this EarningRelease.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The symbol of this EarningRelease.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this EarningRelease.

        Symbol.  # noqa: E501

        :param symbol: The symbol of this EarningRelease.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def date(self):
        """Gets the date of this EarningRelease.  # noqa: E501

        Date.  # noqa: E501

        :return: The date of this EarningRelease.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this EarningRelease.

        Date.  # noqa: E501

        :param date: The date of this EarningRelease.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def hour(self):
        """Gets the hour of this EarningRelease.  # noqa: E501

        Indicates whether the earnings is announced before market open(<code>bmo</code>), after market close(<code>amc</code>), or during market hour(<code>dmh</code>).  # noqa: E501

        :return: The hour of this EarningRelease.  # noqa: E501
        :rtype: str
        """
        return self._hour

    @hour.setter
    def hour(self, hour):
        """Sets the hour of this EarningRelease.

        Indicates whether the earnings is announced before market open(<code>bmo</code>), after market close(<code>amc</code>), or during market hour(<code>dmh</code>).  # noqa: E501

        :param hour: The hour of this EarningRelease.  # noqa: E501
        :type: str
        """

        self._hour = hour

    @property
    def year(self):
        """Gets the year of this EarningRelease.  # noqa: E501

        Earnings year.  # noqa: E501

        :return: The year of this EarningRelease.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this EarningRelease.

        Earnings year.  # noqa: E501

        :param year: The year of this EarningRelease.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def quarter(self):
        """Gets the quarter of this EarningRelease.  # noqa: E501

        Earnings quarter.  # noqa: E501

        :return: The quarter of this EarningRelease.  # noqa: E501
        :rtype: int
        """
        return self._quarter

    @quarter.setter
    def quarter(self, quarter):
        """Sets the quarter of this EarningRelease.

        Earnings quarter.  # noqa: E501

        :param quarter: The quarter of this EarningRelease.  # noqa: E501
        :type: int
        """

        self._quarter = quarter

    @property
    def eps_estimate(self):
        """Gets the eps_estimate of this EarningRelease.  # noqa: E501

        EPS estimate.  # noqa: E501

        :return: The eps_estimate of this EarningRelease.  # noqa: E501
        :rtype: float
        """
        return self._eps_estimate

    @eps_estimate.setter
    def eps_estimate(self, eps_estimate):
        """Sets the eps_estimate of this EarningRelease.

        EPS estimate.  # noqa: E501

        :param eps_estimate: The eps_estimate of this EarningRelease.  # noqa: E501
        :type: float
        """

        self._eps_estimate = eps_estimate

    @property
    def eps_actual(self):
        """Gets the eps_actual of this EarningRelease.  # noqa: E501

        EPS actual.  # noqa: E501

        :return: The eps_actual of this EarningRelease.  # noqa: E501
        :rtype: float
        """
        return self._eps_actual

    @eps_actual.setter
    def eps_actual(self, eps_actual):
        """Sets the eps_actual of this EarningRelease.

        EPS actual.  # noqa: E501

        :param eps_actual: The eps_actual of this EarningRelease.  # noqa: E501
        :type: float
        """

        self._eps_actual = eps_actual

    @property
    def revenue_estimate(self):
        """Gets the revenue_estimate of this EarningRelease.  # noqa: E501

        Revenue estimate.  # noqa: E501

        :return: The revenue_estimate of this EarningRelease.  # noqa: E501
        :rtype: int
        """
        return self._revenue_estimate

    @revenue_estimate.setter
    def revenue_estimate(self, revenue_estimate):
        """Sets the revenue_estimate of this EarningRelease.

        Revenue estimate.  # noqa: E501

        :param revenue_estimate: The revenue_estimate of this EarningRelease.  # noqa: E501
        :type: int
        """

        self._revenue_estimate = revenue_estimate

    @property
    def revenue_actual(self):
        """Gets the revenue_actual of this EarningRelease.  # noqa: E501

        Revenue actual.  # noqa: E501

        :return: The revenue_actual of this EarningRelease.  # noqa: E501
        :rtype: int
        """
        return self._revenue_actual

    @revenue_actual.setter
    def revenue_actual(self, revenue_actual):
        """Sets the revenue_actual of this EarningRelease.

        Revenue actual.  # noqa: E501

        :param revenue_actual: The revenue_actual of this EarningRelease.  # noqa: E501
        :type: int
        """

        self._revenue_actual = revenue_actual

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EarningRelease):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EarningRelease):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class Company(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'age': 'int',
        'title': 'str',
        'since': 'str',
        'sex': 'str',
        'compensation': 'int',
        'currency': 'str'
    }

    attribute_map = {
        'name': 'name',
        'age': 'age',
        'title': 'title',
        'since': 'since',
        'sex': 'sex',
        'compensation': 'compensation',
        'currency': 'currency'
    }

    def __init__(self, name=None, age=None, title=None, since=None, sex=None, compensation=None, currency=None, local_vars_configuration=None):  # noqa: E501
        """Company - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._age = None
        self._title = None
        self._since = None
        self._sex = None
        self._compensation = None
        self._currency = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if age is not None:
            self.age = age
        if title is not None:
            self.title = title
        if since is not None:
            self.since = since
        if sex is not None:
            self.sex = sex
        if compensation is not None:
            self.compensation = compensation
        if currency is not None:
            self.currency = currency

    @property
    def name(self):
        """Gets the name of this Company.  # noqa: E501

        Executive name  # noqa: E501

        :return: The name of this Company.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Company.

        Executive name  # noqa: E501

        :param name: The name of this Company.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def age(self):
        """Gets the age of this Company.  # noqa: E501

        Age  # noqa: E501

        :return: The age of this Company.  # noqa: E501
        :rtype: int
        """
        return self._age

    @age.setter
    def age(self, age):
        """Sets the age of this Company.

        Age  # noqa: E501

        :param age: The age of this Company.  # noqa: E501
        :type: int
        """

        self._age = age

    @property
    def title(self):
        """Gets the title of this Company.  # noqa: E501

        Title  # noqa: E501

        :return: The title of this Company.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Company.

        Title  # noqa: E501

        :param title: The title of this Company.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def since(self):
        """Gets the since of this Company.  # noqa: E501

        Year appointed  # noqa: E501

        :return: The since of this Company.  # noqa: E501
        :rtype: str
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this Company.

        Year appointed  # noqa: E501

        :param since: The since of this Company.  # noqa: E501
        :type: str
        """

        self._since = since

    @property
    def sex(self):
        """Gets the sex of this Company.  # noqa: E501

        Sex  # noqa: E501

        :return: The sex of this Company.  # noqa: E501
        :rtype: str
        """
        return self._sex

    @sex.setter
    def sex(self, sex):
        """Sets the sex of this Company.

        Sex  # noqa: E501

        :param sex: The sex of this Company.  # noqa: E501
        :type: str
        """

        self._sex = sex

    @property
    def compensation(self):
        """Gets the compensation of this Company.  # noqa: E501

        Total compensation  # noqa: E501

        :return: The compensation of this Company.  # noqa: E501
        :rtype: int
        """
        return self._compensation

    @compensation.setter
    def compensation(self, compensation):
        """Sets the compensation of this Company.

        Total compensation  # noqa: E501

        :param compensation: The compensation of this Company.  # noqa: E501
        :type: int
        """

        self._compensation = compensation

    @property
    def currency(self):
        """Gets the currency of this Company.  # noqa: E501

        Compensation currency  # noqa: E501

        :return: The currency of this Company.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Company.

        Compensation currency  # noqa: E501

        :param currency: The currency of this Company.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Company):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Company):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class Dividends(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'symbol': 'str',
        'date': 'date',
        'amount': 'float',
        'adjusted_amount': 'float',
        'pay_date': 'date',
        'record_date': 'date',
        'declaration_date': 'date',
        'currency': 'str'
    }

    attribute_map = {
        'symbol': 'symbol',
        'date': 'date',
        'amount': 'amount',
        'adjusted_amount': 'adjustedAmount',
        'pay_date': 'payDate',
        'record_date': 'recordDate',
        'declaration_date': 'declarationDate',
        'currency': 'currency'
    }

    def __init__(self, symbol=None, date=None, amount=None, adjusted_amount=None, pay_date=None, record_date=None, declaration_date=None, currency=None, local_vars_configuration=None):  # noqa: E501
        """Dividends - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._symbol = None
        self._date = None
        self._amount = None
        self._adjusted_amount = None
        self._pay_date = None
        self._record_date = None
        self._declaration_date = None
        self._currency = None
        self.discriminator = None

        if symbol is not None:
            self.symbol = symbol
        if date is not None:
            self.date = date
        if amount is not None:
            self.amount = amount
        if adjusted_amount is not None:
            self.adjusted_amount = adjusted_amount
        if pay_date is not None:
            self.pay_date = pay_date
        if record_date is not None:
            self.record_date = record_date
        if declaration_date is not None:
            self.declaration_date = declaration_date
        if currency is not None:
            self.currency = currency

    @property
    def symbol(self):
        """Gets the symbol of this Dividends.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The symbol of this Dividends.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Dividends.

        Symbol.  # noqa: E501

        :param symbol: The symbol of this Dividends.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def date(self):
        """Gets the date of this Dividends.  # noqa: E501

        Ex-Dividend date.  # noqa: E501

        :return: The date of this Dividends.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this Dividends.

        Ex-Dividend date.  # noqa: E501

        :param date: The date of this Dividends.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def amount(self):
        """Gets the amount of this Dividends.  # noqa: E501

        Amount in local currency.  # noqa: E501

        :return: The amount of this Dividends.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Dividends.

        Amount in local currency.  # noqa: E501

        :param amount: The amount of this Dividends.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def adjusted_amount(self):
        """Gets the adjusted_amount of this Dividends.  # noqa: E501

        Adjusted dividend.  # noqa: E501

        :return: The adjusted_amount of this Dividends.  # noqa: E501
        :rtype: float
        """
        return self._adjusted_amount

    @adjusted_amount.setter
    def adjusted_amount(self, adjusted_amount):
        """Sets the adjusted_amount of this Dividends.

        Adjusted dividend.  # noqa: E501

        :param adjusted_amount: The adjusted_amount of this Dividends.  # noqa: E501
        :type: float
        """

        self._adjusted_amount = adjusted_amount

    @property
    def pay_date(self):
        """Gets the pay_date of this Dividends.  # noqa: E501

        Pay date.  # noqa: E501

        :return: The pay_date of this Dividends.  # noqa: E501
        :rtype: date
        """
        return self._pay_date

    @pay_date.setter
    def pay_date(self, pay_date):
        """Sets the pay_date of this Dividends.

        Pay date.  # noqa: E501

        :param pay_date: The pay_date of this Dividends.  # noqa: E501
        :type: date
        """

        self._pay_date = pay_date

    @property
    def record_date(self):
        """Gets the record_date of this Dividends.  # noqa: E501

        Record date.  # noqa: E501

        :return: The record_date of this Dividends.  # noqa: E501
        :rtype: date
        """
        return self._record_date

    @record_date.setter
    def record_date(self, record_date):
        """Sets the record_date of this Dividends.

        Record date.  # noqa: E501

        :param record_date: The record_date of this Dividends.  # noqa: E501
        :type: date
        """

        self._record_date = record_date

    @property
    def declaration_date(self):
        """Gets the declaration_date of this Dividends.  # noqa: E501

        Declaration date.  # noqa: E501

        :return: The declaration_date of this Dividends.  # noqa: E501
        :rtype: date
        """
        return self._declaration_date

    @declaration_date.setter
    def declaration_date(self, declaration_date):
        """Sets the declaration_date of this Dividends.

        Declaration date.  # noqa: E501

        :param declaration_date: The declaration_date of this Dividends.  # noqa: E501
        :type: date
        """

        self._declaration_date = declaration_date

    @property
    def currency(self):
        """Gets the currency of this Dividends.  # noqa: E501

        Currency.  # noqa: E501

        :return: The currency of this Dividends.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Dividends.

        Currency.  # noqa: E501

        :param currency: The currency of this Dividends.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Dividends):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Dividends):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class CompanyNewsStatistics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'articles_in_last_week': 'int',
        'buzz': 'float',
        'weekly_average': 'float'
    }

    attribute_map = {
        'articles_in_last_week': 'articlesInLastWeek',
        'buzz': 'buzz',
        'weekly_average': 'weeklyAverage'
    }

    def __init__(self, articles_in_last_week=None, buzz=None, weekly_average=None, local_vars_configuration=None):  # noqa: E501
        """CompanyNewsStatistics - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._articles_in_last_week = None
        self._buzz = None
        self._weekly_average = None
        self.discriminator = None

        if articles_in_last_week is not None:
            self.articles_in_last_week = articles_in_last_week
        if buzz is not None:
            self.buzz = buzz
        if weekly_average is not None:
            self.weekly_average = weekly_average

    @property
    def articles_in_last_week(self):
        """Gets the articles_in_last_week of this CompanyNewsStatistics.  # noqa: E501

          # noqa: E501

        :return: The articles_in_last_week of this CompanyNewsStatistics.  # noqa: E501
        :rtype: int
        """
        return self._articles_in_last_week

    @articles_in_last_week.setter
    def articles_in_last_week(self, articles_in_last_week):
        """Sets the articles_in_last_week of this CompanyNewsStatistics.

          # noqa: E501

        :param articles_in_last_week: The articles_in_last_week of this CompanyNewsStatistics.  # noqa: E501
        :type: int
        """

        self._articles_in_last_week = articles_in_last_week

    @property
    def buzz(self):
        """Gets the buzz of this CompanyNewsStatistics.  # noqa: E501

          # noqa: E501

        :return: The buzz of this CompanyNewsStatistics.  # noqa: E501
        :rtype: float
        """
        return self._buzz

    @buzz.setter
    def buzz(self, buzz):
        """Sets the buzz of this CompanyNewsStatistics.

          # noqa: E501

        :param buzz: The buzz of this CompanyNewsStatistics.  # noqa: E501
        :type: float
        """

        self._buzz = buzz

    @property
    def weekly_average(self):
        """Gets the weekly_average of this CompanyNewsStatistics.  # noqa: E501

          # noqa: E501

        :return: The weekly_average of this CompanyNewsStatistics.  # noqa: E501
        :rtype: float
        """
        return self._weekly_average

    @weekly_average.setter
    def weekly_average(self, weekly_average):
        """Sets the weekly_average of this CompanyNewsStatistics.

          # noqa: E501

        :param weekly_average: The weekly_average of this CompanyNewsStatistics.  # noqa: E501
        :type: float
        """

        self._weekly_average = weekly_average

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompanyNewsStatistics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompanyNewsStatistics):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from docifier-test.configuration import Configuration


class Filing(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_number': 'str',
        'symbol': 'str',
        'cik': 'str',
        'form': 'str',
        'filed_date': 'datetime',
        'accepted_date': 'datetime',
        'report_url': 'str',
        'filing_url': 'str'
    }

    attribute_map = {
        'access_number': 'accessNumber',
        'symbol': 'symbol',
        'cik': 'cik',
        'form': 'form',
        'filed_date': 'filedDate',
        'accepted_date': 'acceptedDate',
        'report_url': 'reportUrl',
        'filing_url': 'filingUrl'
    }

    def __init__(self, access_number=None, symbol=None, cik=None, form=None, filed_date=None, accepted_date=None, report_url=None, filing_url=None, local_vars_configuration=None):  # noqa: E501
        """Filing - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_number = None
        self._symbol = None
        self._cik = None
        self._form = None
        self._filed_date = None
        self._accepted_date = None
        self._report_url = None
        self._filing_url = None
        self.discriminator = None

        if access_number is not None:
            self.access_number = access_number
        if symbol is not None:
            self.symbol = symbol
        if cik is not None:
            self.cik = cik
        if form is not None:
            self.form = form
        if filed_date is not None:
            self.filed_date = filed_date
        if accepted_date is not None:
            self.accepted_date = accepted_date
        if report_url is not None:
            self.report_url = report_url
        if filing_url is not None:
            self.filing_url = filing_url

    @property
    def access_number(self):
        """Gets the access_number of this Filing.  # noqa: E501

        Access number.  # noqa: E501

        :return: The access_number of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._access_number

    @access_number.setter
    def access_number(self, access_number):
        """Sets the access_number of this Filing.

        Access number.  # noqa: E501

        :param access_number: The access_number of this Filing.  # noqa: E501
        :type: str
        """

        self._access_number = access_number

    @property
    def symbol(self):
        """Gets the symbol of this Filing.  # noqa: E501

        Symbol.  # noqa: E501

        :return: The symbol of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this Filing.

        Symbol.  # noqa: E501

        :param symbol: The symbol of this Filing.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def cik(self):
        """Gets the cik of this Filing.  # noqa: E501

        CIK.  # noqa: E501

        :return: The cik of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._cik

    @cik.setter
    def cik(self, cik):
        """Sets the cik of this Filing.

        CIK.  # noqa: E501

        :param cik: The cik of this Filing.  # noqa: E501
        :type: str
        """

        self._cik = cik

    @property
    def form(self):
        """Gets the form of this Filing.  # noqa: E501

        Form type.  # noqa: E501

        :return: The form of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this Filing.

        Form type.  # noqa: E501

        :param form: The form of this Filing.  # noqa: E501
        :type: str
        """

        self._form = form

    @property
    def filed_date(self):
        """Gets the filed_date of this Filing.  # noqa: E501

        Filed date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The filed_date of this Filing.  # noqa: E501
        :rtype: datetime
        """
        return self._filed_date

    @filed_date.setter
    def filed_date(self, filed_date):
        """Sets the filed_date of this Filing.

        Filed date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param filed_date: The filed_date of this Filing.  # noqa: E501
        :type: datetime
        """

        self._filed_date = filed_date

    @property
    def accepted_date(self):
        """Gets the accepted_date of this Filing.  # noqa: E501

        Accepted date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :return: The accepted_date of this Filing.  # noqa: E501
        :rtype: datetime
        """
        return self._accepted_date

    @accepted_date.setter
    def accepted_date(self, accepted_date):
        """Sets the accepted_date of this Filing.

        Accepted date <code>%Y-%m-%d %H:%M:%S</code>.  # noqa: E501

        :param accepted_date: The accepted_date of this Filing.  # noqa: E501
        :type: datetime
        """

        self._accepted_date = accepted_date

    @property
    def report_url(self):
        """Gets the report_url of this Filing.  # noqa: E501

        Report's URL.  # noqa: E501

        :return: The report_url of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._report_url

    @report_url.setter
    def report_url(self, report_url):
        """Sets the report_url of this Filing.

        Report's URL.  # noqa: E501

        :param report_url: The report_url of this Filing.  # noqa: E501
        :type: str
        """

        self._report_url = report_url

    @property
    def filing_url(self):
        """Gets the filing_url of this Filing.  # noqa: E501

        Filing's URL.  # noqa: E501

        :return: The filing_url of this Filing.  # noqa: E501
        :rtype: str
        """
        return self._filing_url

    @filing_url.setter
    def filing_url(self, filing_url):
        """Sets the filing_url of this Filing.

        Filing's URL.  # noqa: E501

        :param filing_url: The filing_url of this Filing.  # noqa: E501
        :type: str
        """

        self._filing_url = filing_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Filing):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Filing):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import docifier-test
from docifier-test.models.filing import Filing  # noqa: E501
from docifier-test.rest import ApiException

class TestFiling(unittest.TestCase):
    """Filing unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Filing
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = docifier-test.models.filing.Filing()  # noqa: E501
        if include_optional :
            return Filing(
                access_number = '0', 
                symbol = '0', 
                cik = '0', 
                form = '0', 
                filed_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                accepted_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                report_url = '0', 
                filing_url = '0'
            )
        else :
            return Filing(
        )

    def testFiling(self):
        """Test Filing"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
